.deploys th, .deploys td {
    text-align: left;
}

.deploys td.app {
    word-break: break-word;
    word-wrap: break-word;
}

.deploys .to-right {
    text-align: right;
}

#fileselect {
    display: block;
}

#filedrag {
    display: block;
    font-weight: bold;
    text-align: center;
    padding: 1em 0;
    margin: 1em 0;
    color: #555;
    border: 2px dashed #555;
    border-radius: 7px;
    cursor: default;
}

#filedrag.hover {
    color: #f00;
    border-color: #f00;
    border-style: solid;
    box-shadow: inset 0 3px 4px #888;
}

#output {
    color: #fff;
    background-color: #333;
    border-radius: 3px;
    padding: 10px 20px;
    position: relative;
    min-height: 15px;
}

#output img {
    position: absolute;
    right: 10px;
    top: 10px;
}

.loader {
  font-size: 3px;
  width: 8em;
  height: 8em;
  border-radius: 50%;
  background: #666;
  background: -moz-linear-gradient(left, #666 10%, rgba(255, 255, 255, 0) 42%);
  background: -webkit-linear-gradient(left, #666 10%, rgba(255, 255, 255, 0) 42%);
  background: -o-linear-gradient(left, #666 10%, rgba(255, 255, 255, 0) 42%);
  background: -ms-linear-gradient(left, #666 10%, rgba(255, 255, 255, 0) 42%);
  background: linear-gradient(to right, #666 10%, rgba(255, 255, 255, 0) 42%);
  position: relative;
  -webkit-animation: load3 1.4s infinite linear;
  animation: load3 1.4s infinite linear;
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
}
.loader:before {
  width: 50%;
  height: 50%;
  background: #666;
  border-radius: 100% 0 0 0;
  position: absolute;
  top: 0;
  left: 0;
  content: '';
}
.loader:after {
  background: #fcf8e3;
  width: 75%;
  height: 75%;
  border-radius: 50%;
  content: '';
  margin: auto;
  position: absolute;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
}
@-webkit-keyframes load3 {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
@keyframes load3 {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
