{% extends "base.html" %}
{% load staticfiles %}

{% block extra_css %}
{{ block.super }}
<link rel="stylesheet" href="{% static "css/apps/pages/list.css" %}">
<link rel="stylesheet" href="{% static "css/loader.css" %}">
<link rel="stylesheet" href="{% static "css/apps/components/icono.min.css" %}">
{% endblock %}

{% block sidebar %}
{% include "sidebar.html" with active="apps" %}
{% endblock %}

{% block bar %}
<div class="bar">
  <a href="/">dashboard</a> <span class="arrow">></span>
	apps
</div>
{% endblock %}

{% block header %}
<h1>Apps</h1>
{% endblock %}

{% block content %}
<div class="container-fluid">
	<div class="row">
		<div class="col-md-12" id="list-container">
		</div>
	</div>
</div>
{% endblock %}

{% block extra_js %}
<script src="{% static "js/list.js" %}"></script>
{% endblock %}
